==> eam-wshub-proxyclient-11.6-0-sources.jar: net/datastream/schemas/mp_fields/PAGEBLOCKS.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAGEBLOCK" maxOccurs="50"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "pageblock"
})
@XmlRootElement(name = "PAGEBLOCKS")
public class PAGEBLOCKS {

    @XmlElement(name = "PAGEBLOCK", required = true)
    protected List<PAGEBLOCK> pageblock;

    /**
     * Gets the value of the pageblock property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the pageblock property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPAGEBLOCK().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PAGEBLOCK }
     * 
     * 
     */
    public List<PAGEBLOCK> getPAGEBLOCK() {
        if (pageblock == null) {
            pageblock = new ArrayList<PAGEBLOCK>();
        }
        return this.pageblock;
    }

}

==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_fields/PAGEBLOCKS.java <==

package net.datastream.schemas.mp_fields;

import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PAGEBLOCK" maxOccurs="50"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "pageblock"
})
@XmlRootElement(name = "PAGEBLOCKS")
public class PAGEBLOCKS {

    @XmlElement(name = "PAGEBLOCK", required = true)
    protected List<PAGEBLOCK> pageblock;

    /**
     * Gets the value of the pageblock property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the pageblock property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getPAGEBLOCK().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link PAGEBLOCK }
     * 
     * 
     */
    public List<PAGEBLOCK> getPAGEBLOCK() {
        if (pageblock == null) {
            pageblock = new ArrayList<PAGEBLOCK>();
        }
        return this.pageblock;
    }

}
